@@ -2,7 +2,8 @@
 Open Asset Import Library (assimp)
 ----------------------------------------------------------------------
 
-Copyright (c) 2006-2015, assimp team
+Copyright (c) 2006-2017, assimp team
+
 All rights reserved.
 
 Redistribution and use of this software in source and binary forms,
@@ -42,8 +43,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "OgreStructs.h"
 #include "TinyFormatter.h"
-#include "../include/assimp/scene.h"
-#include "../include/assimp/DefaultLogger.hpp"
+#include <assimp/scene.h>
+#include <assimp/DefaultLogger.hpp>
 #include "Exceptional.h"
 
 
@@ -258,12 +259,11 @@ void IVertexData::AddVertexMapping(uint32_t oldIndex, uint32_t newIndex)
 
 void IVertexData::BoneAssignmentsForVertex(uint32_t currentIndex, uint32_t newIndex, VertexBoneAssignmentList &dest) const
 {
-    for (VertexBoneAssignmentList::const_iterator iter=boneAssignments.begin(), end=boneAssignments.end();
-        iter!=end; ++iter)
+    for (const auto &boneAssign : boneAssignments)
     {
-        if (iter->vertexIndex == currentIndex)
+        if (boneAssign.vertexIndex == currentIndex)
         {
-            VertexBoneAssignment a = (*iter);
+            VertexBoneAssignment a = boneAssign;
             a.vertexIndex = newIndex;
             dest.push_back(a);
         }
@@ -275,12 +275,12 @@ AssimpVertexBoneWeightList IVertexData::AssimpBoneWeights(size_t vertices)
     AssimpVertexBoneWeightList weights;
     for(size_t vi=0; vi<vertices; ++vi)
     {
-        VertexBoneAssignmentList &vertexWeights = boneAssignmentsMap[vi];
+        VertexBoneAssignmentList &vertexWeights = boneAssignmentsMap[static_cast<unsigned int>(vi)];
         for (VertexBoneAssignmentList::const_iterator iter=vertexWeights.begin(), end=vertexWeights.end();
             iter!=end; ++iter)
         {
             std::vector<aiVertexWeight> &boneWeights = weights[iter->boneIndex];
-            boneWeights.push_back(aiVertexWeight(vi, iter->weight));
+            boneWeights.push_back(aiVertexWeight(static_cast<unsigned int>(vi), iter->weight));
         }
     }
     return weights;
@@ -289,10 +289,9 @@ AssimpVertexBoneWeightList IVertexData::AssimpBoneWeights(size_t vertices)
 std::set<uint16_t> IVertexData::ReferencedBonesByWeights() const
 {
     std::set<uint16_t> referenced;
-    for (VertexBoneAssignmentList::const_iterator iter=boneAssignments.begin(), end=boneAssignments.end();
-        iter!=end; ++iter)
+    for (const auto &boneAssign : boneAssignments)
     {
-        referenced.insert(iter->boneIndex);
+        referenced.insert(boneAssign.boneIndex);
     }
     return referenced;
 }
@@ -318,10 +317,10 @@ void VertexData::Reset()
 uint32_t VertexData::VertexSize(uint16_t source) const
 {
     uint32_t size = 0;
-    for(VertexElementList::const_iterator iter=vertexElements.begin(), end=vertexElements.end(); iter != end; ++iter)
+    for(const auto &element : vertexElements)
     {
-        if (iter->source == source)
-            size += iter->Size();
+        if (element.source == source)
+            size += static_cast<uint32_t>(element.Size());
     }
     return size;
 }
@@ -335,9 +334,8 @@ MemoryStream *VertexData::VertexBuffer(uint16_t source)
 
 VertexElement *VertexData::GetVertexElement(VertexElement::Semantic semantic, uint16_t index)
 {
-    for(VertexElementList::iterator iter=vertexElements.begin(), end=vertexElements.end(); iter != end; ++iter)
+    for(auto & element : vertexElements)
     {
-        VertexElement &element = (*iter);
         if (element.semantic == semantic && element.index == index)
             return &element;
     }
@@ -407,10 +405,13 @@ size_t IndexData::FaceSize() const
 
 // Mesh
 
-Mesh::Mesh() :
-    hasSkeletalAnimations(false),
-    skeleton(NULL),
-    sharedVertexData(NULL)
+Mesh::Mesh() 
+    : hasSkeletalAnimations(false)
+    , skeleton(NULL)
+    , sharedVertexData(NULL)
+    , subMeshes()
+    , animations()
+    , poses()
 {
 }
 
@@ -424,16 +425,16 @@ void Mesh::Reset()
     OGRE_SAFE_DELETE(skeleton)
     OGRE_SAFE_DELETE(sharedVertexData)
 
-    for(size_t i=0, len=subMeshes.size(); i<len; ++i) {
-        OGRE_SAFE_DELETE(subMeshes[i])
+    for(auto &mesh : subMeshes) {
+        OGRE_SAFE_DELETE(mesh)
     }
     subMeshes.clear();
-    for(size_t i=0, len=animations.size(); i<len; ++i) {
-        OGRE_SAFE_DELETE(animations[i])
+    for(auto &anim : animations) {
+        OGRE_SAFE_DELETE(anim)
     }
     animations.clear();
-    for(size_t i=0, len=poses.size(); i<len; ++i) {
-        OGRE_SAFE_DELETE(poses[i])
+    for(auto &pose : poses) {
+        OGRE_SAFE_DELETE(pose)
     }
     poses.clear();
 }
@@ -443,18 +444,24 @@ size_t Mesh::NumSubMeshes() const
     return subMeshes.size();
 }
 
-SubMesh *Mesh::GetSubMesh(uint16_t index) const
+SubMesh *Mesh::GetSubMesh( size_t index ) const
 {
-    for(size_t i=0; i<subMeshes.size(); ++i)
-        if (subMeshes[i]->index == index)
-            return subMeshes[i];
+    for ( size_t i = 0; i < subMeshes.size(); ++i ) {
+        if ( subMeshes[ i ]->index == index ) {
+            return subMeshes[ i ];
+        }
+    }
     return 0;
 }
 
 void Mesh::ConvertToAssimpScene(aiScene* dest)
 {
+    if ( nullptr == dest ) {
+        return;
+    }
+
     // Setup
-    dest->mNumMeshes = NumSubMeshes();
+    dest->mNumMeshes = static_cast<unsigned int>(NumSubMeshes());
     dest->mMeshes = new aiMesh*[dest->mNumMeshes];
 
     // Create root node
@@ -463,10 +470,9 @@ void Mesh::ConvertToAssimpScene(aiScene* dest)
     dest->mRootNode->mMeshes = new unsigned int[dest->mRootNode->mNumMeshes];
 
     // Export meshes
-    for(size_t i=0; i<dest->mNumMeshes; ++i)
-    {
+    for(size_t i=0; i<dest->mNumMeshes; ++i) {
         dest->mMeshes[i] = subMeshes[i]->ConvertToAssimpMesh(this);
-        dest->mRootNode->mMeshes[i] = i;
+        dest->mRootNode->mMeshes[i] = static_cast<unsigned int>(i);
     }
 
     // Export skeleton
@@ -476,7 +482,7 @@ void Mesh::ConvertToAssimpScene(aiScene* dest)
         if (!skeleton->bones.empty())
         {
             BoneList rootBones = skeleton->RootBones();
-            dest->mRootNode->mNumChildren = rootBones.size();
+            dest->mRootNode->mNumChildren = static_cast<unsigned int>(rootBones.size());
             dest->mRootNode->mChildren = new aiNode*[dest->mRootNode->mNumChildren];
 
             for(size_t i=0, len=rootBones.size(); i<len; ++i)
@@ -488,7 +494,7 @@ void Mesh::ConvertToAssimpScene(aiScene* dest)
         // Animations
         if (!skeleton->animations.empty())
         {
-            dest->mNumAnimations = skeleton->animations.size();
+            dest->mNumAnimations = static_cast<unsigned int>(skeleton->animations.size());
             dest->mAnimations = new aiAnimation*[dest->mNumAnimations];
 
             for(size_t i=0, len=skeleton->animations.size(); i<len; ++i)
@@ -567,7 +573,7 @@ aiMesh *SubMesh::ConvertToAssimpMesh(Mesh *parent)
 
     // Assimp required unique vertices, we need to convert from Ogres shared indexing.
     size_t uniqueVertexCount = dest->mNumFaces * 3;
-    dest->mNumVertices = uniqueVertexCount;
+    dest->mNumVertices = static_cast<unsigned int>(uniqueVertexCount);
     dest->mVertices = new aiVector3D[dest->mNumVertices];
 
     // Source streams
@@ -599,7 +605,7 @@ aiMesh *SubMesh::ConvertToAssimpMesh(Mesh *parent)
     {
         if (uv1Element->type == VertexElement::VET_FLOAT2 || uv1Element->type == VertexElement::VET_FLOAT3)
         {
-            dest->mNumUVComponents[0] = uv1Element->ComponentCount();
+            dest->mNumUVComponents[0] = static_cast<unsigned int>(uv1Element->ComponentCount());
             dest->mTextureCoords[0] = new aiVector3D[dest->mNumVertices];
         }
         else
@@ -612,7 +618,7 @@ aiMesh *SubMesh::ConvertToAssimpMesh(Mesh *parent)
     {
         if (uv2Element->type == VertexElement::VET_FLOAT2 || uv2Element->type == VertexElement::VET_FLOAT3)
         {
-            dest->mNumUVComponents[1] = uv2Element->ComponentCount();
+            dest->mNumUVComponents[1] = static_cast<unsigned int>(uv2Element->ComponentCount());
             dest->mTextureCoords[1] = new aiVector3D[dest->mNumVertices];
         }
         else
@@ -660,11 +666,11 @@ aiMesh *SubMesh::ConvertToAssimpMesh(Mesh *parent)
             const size_t newIndex = pos + v;
 
             // Write face index
-            face.mIndices[v] = newIndex;
+            face.mIndices[v] = static_cast<unsigned int>(newIndex);
 
             // Ogres vertex index to ref into the source buffers.
             const size_t ogreVertexIndex = ogreFace.mIndices[v];
-            src->AddVertexMapping(ogreVertexIndex, newIndex);
+            src->AddVertexMapping(static_cast<uint32_t>(ogreVertexIndex), static_cast<uint32_t>(newIndex));
 
             // Position
             positions->Seek((vWidthPosition * ogreVertexIndex) + positionsElement->offset, aiOrigin_SET);
@@ -699,7 +705,7 @@ aiMesh *SubMesh::ConvertToAssimpMesh(Mesh *parent)
         AssimpVertexBoneWeightList weights = src->AssimpBoneWeights(dest->mNumVertices);
         std::set<uint16_t> referencedBones = src->ReferencedBonesByWeights();
 
-        dest->mNumBones = referencedBones.size();
+        dest->mNumBones = static_cast<unsigned int>(referencedBones.size());
         dest->mBones = new aiBone*[dest->mNumBones];
 
         size_t assimpBoneIndex = 0;
@@ -731,8 +737,8 @@ void MeshXml::Reset()
     OGRE_SAFE_DELETE(skeleton)
     OGRE_SAFE_DELETE(sharedVertexData)
 
-    for(size_t i=0, len=subMeshes.size(); i<len; ++i) {
-        OGRE_SAFE_DELETE(subMeshes[i])
+    for(auto &mesh : subMeshes) {
+        OGRE_SAFE_DELETE(mesh)
     }
     subMeshes.clear();
 }
@@ -753,7 +759,7 @@ SubMeshXml *MeshXml::GetSubMesh(uint16_t index) const
 void MeshXml::ConvertToAssimpScene(aiScene* dest)
 {
     // Setup
-    dest->mNumMeshes = NumSubMeshes();
+    dest->mNumMeshes = static_cast<unsigned int>(NumSubMeshes());
     dest->mMeshes = new aiMesh*[dest->mNumMeshes];
 
     // Create root node
@@ -765,7 +771,7 @@ void MeshXml::ConvertToAssimpScene(aiScene* dest)
     for(size_t i=0; i<dest->mNumMeshes; ++i)
     {
         dest->mMeshes[i] = subMeshes[i]->ConvertToAssimpMesh(this);
-        dest->mRootNode->mMeshes[i] = i;
+        dest->mRootNode->mMeshes[i] = static_cast<unsigned int>(i);
     }
 
     // Export skeleton
@@ -775,7 +781,7 @@ void MeshXml::ConvertToAssimpScene(aiScene* dest)
         if (!skeleton->bones.empty())
         {
             BoneList rootBones = skeleton->RootBones();
-            dest->mRootNode->mNumChildren = rootBones.size();
+            dest->mRootNode->mNumChildren = static_cast<unsigned int>(rootBones.size());
             dest->mRootNode->mChildren = new aiNode*[dest->mRootNode->mNumChildren];
 
             for(size_t i=0, len=rootBones.size(); i<len; ++i)
@@ -787,7 +793,7 @@ void MeshXml::ConvertToAssimpScene(aiScene* dest)
         // Animations
         if (!skeleton->animations.empty())
         {
-            dest->mNumAnimations = skeleton->animations.size();
+            dest->mNumAnimations = static_cast<unsigned int>(skeleton->animations.size());
             dest->mAnimations = new aiAnimation*[dest->mNumAnimations];
 
             for(size_t i=0, len=skeleton->animations.size(); i<len; ++i)
@@ -835,7 +841,7 @@ aiMesh *SubMeshXml::ConvertToAssimpMesh(MeshXml *parent)
 
     // Assimp required unique vertices, we need to convert from Ogres shared indexing.
     size_t uniqueVertexCount = dest->mNumFaces * 3;
-    dest->mNumVertices = uniqueVertexCount;
+    dest->mNumVertices = static_cast<unsigned int>(uniqueVertexCount);
     dest->mVertices = new aiVector3D[dest->mNumVertices];
 
     VertexDataXml *src = (!usesSharedVertexData ? vertexData : parent->sharedVertexData);
@@ -870,11 +876,11 @@ aiMesh *SubMeshXml::ConvertToAssimpMesh(MeshXml *parent)
             const size_t newIndex = pos + v;
 
             // Write face index
-            face.mIndices[v] = newIndex;
+            face.mIndices[v] = static_cast<unsigned int>(newIndex);
 
             // Ogres vertex index to ref into the source buffers.
             const size_t ogreVertexIndex = ogreFace.mIndices[v];
-            src->AddVertexMapping(ogreVertexIndex, newIndex);
+            src->AddVertexMapping(static_cast<uint32_t>(ogreVertexIndex), static_cast<uint32_t>(newIndex));
 
             // Position
             dest->mVertices[newIndex] = src->positions[ogreVertexIndex];
@@ -899,7 +905,7 @@ aiMesh *SubMeshXml::ConvertToAssimpMesh(MeshXml *parent)
         AssimpVertexBoneWeightList weights = src->AssimpBoneWeights(dest->mNumVertices);
         std::set<uint16_t> referencedBones = src->ReferencedBonesByWeights();
 
-        dest->mNumBones = referencedBones.size();
+        dest->mNumBones = static_cast<unsigned int>(referencedBones.size());
         dest->mBones = new aiBone*[dest->mNumBones];
 
         size_t assimpBoneIndex = 0;
@@ -953,7 +959,7 @@ aiAnimation *Animation::ConvertToAssimpAnimation()
     // Tracks
     if (!tracks.empty())
     {
-        anim->mNumChannels = tracks.size();
+        anim->mNumChannels = static_cast<unsigned int>(tracks.size());
         anim->mChannels = new aiNodeAnim*[anim->mNumChannels];
 
         for(size_t i=0, len=tracks.size(); i<len; ++i)
@@ -980,12 +986,12 @@ Skeleton::~Skeleton()
 
 void Skeleton::Reset()
 {
-    for(size_t i=0, len=bones.size(); i<len; ++i) {
-        OGRE_SAFE_DELETE(bones[i])
+    for(auto &bone : bones) {
+        OGRE_SAFE_DELETE(bone)
     }
     bones.clear();
-    for(size_t i=0, len=animations.size(); i<len; ++i) {
-        OGRE_SAFE_DELETE(animations[i])
+    for(auto &anim : animations) {
+        OGRE_SAFE_DELETE(anim)
     }
     animations.clear();
 }
@@ -1074,11 +1080,11 @@ void Bone::CalculateWorldMatrixAndDefaultPose(Skeleton *skeleton)
     defaultPose = aiMatrix4x4(scale, rotation, position);
 
     // Recursively for all children now that the parent matrix has been calculated.
-    for (size_t i=0, len=children.size(); i<len; ++i)
+    for (auto boneId : children)
     {
-        Bone *child = skeleton->BoneById(children[i]);
+        Bone *child = skeleton->BoneById(boneId);
         if (!child) {
-            throw DeadlyImportError(Formatter::format() << "CalculateWorldMatrixAndDefaultPose: Failed to find child bone " << children[i] << " for parent " << id << " " << name);
+            throw DeadlyImportError(Formatter::format() << "CalculateWorldMatrixAndDefaultPose: Failed to find child bone " << boneId << " for parent " << id << " " << name);
         }
         child->CalculateWorldMatrixAndDefaultPose(skeleton);
     }
@@ -1094,7 +1100,7 @@ aiNode *Bone::ConvertToAssimpNode(Skeleton *skeleton, aiNode *parentNode)
     // Children
     if (!children.empty())
     {
-        node->mNumChildren = children.size();
+        node->mNumChildren = static_cast<unsigned int>(children.size());
         node->mChildren = new aiNode*[node->mNumChildren];
 
         for(size_t i=0, len=children.size(); i<len; ++i)
@@ -1117,7 +1123,7 @@ aiBone *Bone::ConvertToAssimpBone(Skeleton * /*parent*/, const std::vector<aiVer
 
     if (!boneWeights.empty())
     {
-        bone->mNumWeights = boneWeights.size();
+        bone->mNumWeights = static_cast<unsigned int>(boneWeights.size());
         bone->mWeights = new aiVertexWeight[boneWeights.size()];
         memcpy(bone->mWeights, &boneWeights[0], boneWeights.size() * sizeof(aiVertexWeight));
     }
@@ -1153,9 +1159,9 @@ aiNodeAnim *VertexAnimationTrack::ConvertToAssimpAnimationNode(Skeleton *skeleto
     nodeAnim->mPositionKeys = new aiVectorKey[numKeyframes];
     nodeAnim->mRotationKeys = new aiQuatKey[numKeyframes];
     nodeAnim->mScalingKeys = new aiVectorKey[numKeyframes];
-    nodeAnim->mNumPositionKeys = numKeyframes;
-    nodeAnim->mNumRotationKeys = numKeyframes;
-    nodeAnim->mNumScalingKeys  = numKeyframes;
+    nodeAnim->mNumPositionKeys = static_cast<unsigned int>(numKeyframes);
+    nodeAnim->mNumRotationKeys = static_cast<unsigned int>(numKeyframes);
+    nodeAnim->mNumScalingKeys  = static_cast<unsigned int>(numKeyframes);
 
     for(size_t kfi=0; kfi<numKeyframes; ++kfi)
     {
