@@ -60,7 +60,7 @@ that it has not been implemented yet and some (most ...) formats lack proper spe
 <b>Stanford Ply</b> ( <i>*.ply</i> )<br>
 <b>TrueSpace</b> ( <i>*.cob, *.scn</i> )<sup>2</sup><br><br>
 </tt>
-See the @link importer_notes Importer Notes Page @endlink for informations, what a specific importer can do and what not.
+See the @link importer_notes Importer Notes Page @endlink for information, what a specific importer can do and what not.
 Note that although this paper claims to be the official documentation,
 http://assimp.sourceforge.net/main_features_formats.html
 <br>is usually the most up-to-date list of file formats supported by the library. <br>
@@ -81,7 +81,7 @@ formats handle the required endian conversion correctly, so large parts of the l
 
 The assimp linker library and viewer application are provided under the BSD 3-clause license. This basically means
 that you are free to use it in open- or closed-source projects, for commercial or non-commercial purposes as you like
-as long as you retain the license informations and take own responsibility for what you do with it. For details see
+as long as you retain the license information and take own responsibility for what you do with it. For details see
 the LICENSE file.
 
 You can find test models for almost all formats in the <assimp_root>/test/models directory. Beware, they're *free*,
@@ -98,7 +98,7 @@ more work. Both ways are described at the @link install Installation page. @endl
 
 When you're done integrating the library into your IDE / project, you can now start using it. There are two separate
 interfaces by which you can access the library: a C++ interface and a C interface using flat functions. While the former
-is easier to handle, the latter also forms a point where other programming languages can connect to. Upto the moment, though,
+is easier to handle, the latter also forms a point where other programming languages can connect to. Up to the moment, though,
 there are no bindings for any other language provided. Have a look at the @link usage Usage page @endlink for a detailed explanation and code examples.
 
 @section main_data Data Structures
@@ -137,7 +137,7 @@ If you develop at Visual Studio 2005 or 2008, you can simply use the pre-built l
 Extract all files to a place of your choice. A directory called "assimp" will be created there. Add the assimp/include path
 to your include paths (Menu-&gt;Extras-&gt;Options-&gt;Projects and Solutions-&gt;VC++ Directories-&gt;Include files)
 and the assimp/lib/&lt;Compiler&gt; path to your linker paths (Menu-&gt;Extras-&gt;Options-&gt;Projects and Solutions-&gt;VC++ Directories-&gt;Library files).
-This is neccessary only once to setup all paths inside you IDE.
+This is necessary only once to setup all paths inside you IDE.
 
 To use the library in your C++ project you have to include either &lt;assimp/Importer.hpp&gt; or &lt;assimp/cimport.h&gt; plus some others starting with &lt;types.h&gt;.
 If you set up your IDE correctly the compiler should be able to find the files. Then you have to add the linker library to your
@@ -145,7 +145,7 @@ project dependencies. Link to <assimp_root>/lib/<config-name>/assimp.lib. config
 project configs. For static linking, use release/debug. See the sections below on this page for more information on the
 other build configs.
 If done correctly you should now be able to compile, link,
-run and use the application. If the linker complains about some integral functions being defined twice you propably have
+run and use the application. If the linker complains about some integral functions being defined twice you probably have
 mixed the runtimes. Recheck the project configuration (project properties -&gt; C++ -&gt; Code generation -&gt; Runtime) if you use
 static runtimes (Multithreaded / Multithreaded Debug) or dynamic runtimes (Multithreaded DLL / Multithreaded Debug DLL).
 Choose the assimp linker lib accordingly.
@@ -287,7 +287,7 @@ bool DoTheImportThing( const std::string& pFile)
 
   // And have it read the given file with some example postprocessing
   // Usually - if speed is not the most important aspect for you - you'll
-  // propably to request more postprocessing than we do in this example.
+  // probably to request more postprocessing than we do in this example.
   const aiScene* scene = importer.ReadFile( pFile,
 	aiProcess_CalcTangentSpace       |
 	aiProcess_Triangulate            |
@@ -310,7 +310,7 @@ bool DoTheImportThing( const std::string& pFile)
 @endcode
 
 What exactly is read from the files and how you interpret it is described at the @ref data page. @endlink The post processing steps that the assimp library can apply to the
-imported data are listed at #aiPostProcessSteps. See the @ref pp Post proccessing page for more details.
+imported data are listed at #aiPostProcessSteps. See the @ref pp Post processing page for more details.
 
 Note that the aiScene data structure returned is declared 'const'. Yes, you can get rid of
 these 5 letters with a simple cast. Yes, you may do that. No, it's not recommended (and it's
@@ -453,7 +453,7 @@ by calling it as a singleton with the requested logging-type. To see how this wo
 using namespace Assimp;
 
 // Create a logger instance
-DefaultLogger::create("",Logger::VERBOSE);
+DefaultLogger::create("", Logger::VERBOSE);
 
 // Now I am ready for logging my stuff
 DefaultLogger::get()->info("this is my info-call");
@@ -472,22 +472,9 @@ Just derivate your own logger from the abstract base class LogStream and overwri
 
 @code
 // Example stream
-class myStream :
-	public LogStream
+class myStream : public LogStream
 {
 public:
-	// Constructor
-	myStream()
-	{
-		// empty
-	}
-
-	// Destructor
-	~myStream()
-	{
-		// empty
-	}
-
 	// Write womethink using your own functionality
 	void write(const char* message)
 	{
@@ -496,10 +483,10 @@ public:
 };
 
 // Select the kinds of messages you want to receive on this log stream
-const unsigned int severity = Logger::DEBUGGING|Logger::INFO|Logger::ERR|Logger::WARN;
+const unsigned int severity = Logger::Debugging|Logger::Info|Logger::Err|Logger::Warn;
 
 // Attaching it to the default logger
-Assimp::DefaultLogger::get()->attachStream( new myStream(), severity );
+Assimp::DefaultLogger::get()->attachStream( new myStream, severity );
 
 @endcode
 
@@ -512,10 +499,10 @@ flag set:
 @code
 
 unsigned int severity = 0;
-severity |= Logger::DEBUGGING;
+severity |= Logger::Debugging;
 
 // Detach debug messages from you self defined stream
-Assimp::DefaultLogger::get()->attachStream( new myStream(), severity );
+Assimp::DefaultLogger::get()->attachStream( new myStream, severity );
 
 @endcode
 
@@ -660,7 +647,7 @@ an index into this array.
 
 An aiMesh is defined by a series of data channels. The presence of these data channels is defined
 by the contents of the imported file: by default there are only those data channels present in the mesh
-that were also found in the file. The only channels guarenteed to be always present are aiMesh::mVertices
+that were also found in the file. The only channels guaranteed to be always present are aiMesh::mVertices
 and aiMesh::mFaces. You can test for the presence of other data by testing the pointers against NULL
 or use the helper functions provided by aiMesh. You may also specify several post processing flags
 at Importer::ReadFile() to let assimp calculate or recalculate additional data channels for you.
@@ -743,6 +730,8 @@ need them at all.
 Normally textures used by assets are stored in separate files, however,
 there are file formats embedding their textures directly into the model file.
 Such textures are loaded into an aiTexture structure.
+For embedded textures, the value of `AI_MATKEY_TEXTURE(textureType, index)` will be `*<index>` where
+`<index>` is the index of the texture in aiScene::mTextures.
 <br>
 There are two cases:
 <br>
@@ -753,7 +742,7 @@ both Direct3D and OpenGL (swizzling the order of the color components might be n
 RGBA8888 has been chosen because it is well-known, easy to use and natively
 supported by nearly all graphics APIs.
 <br>
-<b>2)</b> This applies if aiTexture::mHeight == 0 is fullfilled. Then, texture is stored in a
+<b>2)</b> This applies if aiTexture::mHeight == 0 is fulfilled. Then, texture is stored in a
 "compressed" format such as DDS or PNG. The term "compressed" does not mean that the
 texture data must actually be compressed, however the texture was found in the
 model file as if it was stored in a separate file on the harddisk. Appropriate
@@ -780,7 +769,7 @@ presence of certain properties in a material and retrieve their values.
 
 @section mat_tex Textures
 
-Textures are organized in stacks, each stack being evaluated independently. The final color value from a particular texture stack is used in the shading equation. For example, the computed color value of the diffuse texture stack (aiTextureType_DIFFUSE) is multipled with the amount of incoming diffuse light to obtain the final diffuse color of a pixel.
+Textures are organized in stacks, each stack being evaluated independently. The final color value from a particular texture stack is used in the shading equation. For example, the computed color value of the diffuse texture stack (aiTextureType_DIFFUSE) is multiplied with the amount of incoming diffuse light to obtain the final diffuse color of a pixel.
 
 @code
 
@@ -930,7 +919,7 @@ All material key constants start with 'AI_MATKEY' (it's an ugly macro for histor
     <td><tt>TEXTURE(t,n)</tt></td>
     <td>aiString</td>
     <td>n/a</td>
-	<td>Defines the path to the n'th texture on the stack 't', where 'n' is any value >= 0 and 't' is one of the #aiTextureType enumerated values.</td>
+	<td>Defines the path of the n'th texture on the stack 't', where 'n' is any value >= 0 and 't' is one of the #aiTextureType enumerated values. Either a filepath or `*<index>`, where `<index>` is the index of an embedded texture in aiScene::mTextures.</td>
 	<td>See the 'Textures' section above.</td>
   </tr>
 
@@ -938,7 +927,7 @@ All material key constants start with 'AI_MATKEY' (it's an ugly macro for histor
     <td><tt>TEXBLEND(t,n)</tt></td>
     <td>float</td>
     <td>n/a</td>
-	<td>Defines the strength the n'th texture on the stack 't'. All color components (rgb) are multipled with this factor *before* any further processing is done.</td>
+	<td>Defines the strength the n'th texture on the stack 't'. All color components (rgb) are multiplied with this factor *before* any further processing is done.</td>
 	<td>-</td>
   </tr>
 
@@ -1431,7 +1420,7 @@ IFC file properties (IfcPropertySet) are kept as per-node metadata, see aiNode::
 
 This section contains implementations notes for the OgreXML importer.
 @subsection overview Overview
-Ogre importer is currently optimized for the Blender Ogre exporter, because thats the only one that I use. You can find the Blender Ogre exporter at: http://www.ogre3d.org/forums/viewtopic.php?f=8&t=45922
+Ogre importer is currently optimized for the Blender Ogre exporter, because that's the only one that I use. You can find the Blender Ogre exporter at: http://www.ogre3d.org/forums/viewtopic.php?f=8&t=45922
 
 @subsection what What will be loaded?
 
@@ -1445,7 +1434,7 @@ Skeleton: Skeleton with Bone hierarchy (Position and Rotation, but no Scaling in
 animations with rotation, translation and scaling keys.
 
 @subsection export_Blender How to export Files from Blender
-You can find informations about how to use the Ogreexporter by your own, so here are just some options that you need, so the assimp
+You can find information about how to use the Ogreexporter by your own, so here are just some options that you need, so the assimp
 importer will load everything correctly:
 - Use either "Rendering Material" or "Custom Material" see @ref material
 - do not use "Flip Up Axies to Y"
@@ -1466,7 +1455,7 @@ The skeleton file must have the same name as the mesh file, e.g. fish.mesh.xml a
 The material file can have the same name as the mesh file (if the file is model.mesh or model.mesh.xml the
 loader will try to load model.material),
 or you can use Importer::Importer::SetPropertyString(AI_CONFIG_IMPORT_OGRE_MATERIAL_FILE, "materiafile.material")
-to specify the name of the material file. This is especially usefull if multiply materials a stored in a single file.
+to specify the name of the material file. This is especially useful if multiply materials a stored in a single file.
 The importer will first try to load the material with the same name as the mesh and only if this can't be open try
 to load the alternate material file. The default material filename is "Scene.material".
 
@@ -1554,7 +1543,7 @@ Done! Please, share your loader that everyone can profit from it!
 
 @section properties Properties
 
-You can use properties to chance the behavior of you importer. In order to do so, you have to overide BaseImporter::SetupProperties, and specify
+You can use properties to chance the behavior of you importer. In order to do so, you have to override BaseImporter::SetupProperties, and specify
 you custom properties in config.h. Just have a look to the other AI_CONFIG_IMPORT_* defines and you will understand, how it works.
 
 The properties can be set with Importer::SetProperty***() and can be accessed in your SetupProperties function with Importer::GetProperty***(). You can
@@ -1574,7 +1563,7 @@ But the general rule of thumb is <i>be strict in what you write and tolerant in
 
 <ul>
 <li>
-Take care of endianess issues! Assimp importers mostly support big-endian platforms, which define the <tt>AI_BUILD_BIG_ENDIAN</tt> constant.
+Take care of endianness issues! Assimp importers mostly support big-endian platforms, which define the <tt>AI_BUILD_BIG_ENDIAN</tt> constant.
 See the next section for a list of utilities to simplify this task.
 </li>
 <li>
@@ -1680,7 +1669,7 @@ void xxxxImporter::GetExtensionList(std::set<std::string>& extensions)
 void xxxxImporter::InternReadFile( const std::string& pFile,
 	aiScene* pScene, IOSystem* pIOHandler)
 {
-	boost::scoped_ptr<IOStream> file( pIOHandler->Open( pFile, "rb"));
+	std::unique_ptr<IOStream> file( pIOHandler->Open( pFile, "rb"));
 
 	// Check whether we can read from the file
 	if( file.get() == NULL) {
